/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.lagache.spherevtk;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.lang.Block;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.*;

import java.awt.*;

/**
 * Colocalisation with Ripley function K Significant
 */
@IcyPluginName("Draw Spheres VTK")
@IcyPluginIcon(path = "/3d-spheres-vtk.png")
public class DrawSpheresVTK extends Plugin implements Block {
    VarSequence input_sequence = new VarSequence("Input sequence", null);
    VarDoubleArrayNative x = new VarDoubleArrayNative("x", null);
    VarDoubleArrayNative y = new VarDoubleArrayNative("y", null);
    VarDoubleArrayNative z = new VarDoubleArrayNative("z", null);
    VarString name = new VarString("Name of the overlay", "detections");
    VarColor color = new VarColor("Color", Color.blue);
    VarDouble size = new VarDouble("Size", 1.0);

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("Input Sequence", input_sequence);
        inputMap.add("x", x);
        inputMap.add("y", y);
        inputMap.add("z", z);
        inputMap.add("Size", size);
        inputMap.add("Color", color);
        inputMap.add("Name of the overlay", name);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
    }

    @Override
    public void run() {
        // Add the cross overlay, it becomes active after being added.
        input_sequence.getValue().addOverlay(new SphereVTK(x.getValue(), y.getValue(), z.getValue(), size.getValue(), color.getValue(), name.getValue()));
    }
}
